(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     13682,        458]
NotebookOptionsPosition[     12312,        408]
NotebookOutlinePosition[     12765,        426]
CellTagsIndexPosition[     12722,        423]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Ammonia molecule, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", "=", 
    RowBox[{
     SubscriptBox["H", "L"], "+", 
     SubscriptBox["H", "R"], "+", "V"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ", ",
 StyleBox["V",
  FontSlant->"Italic"],
 " treated as perturbation"
}], "Subsubsection",
 CellChangeTimes->{{3.53001605864143*^9, 3.530016118181604*^9}}],

Cell[TextData[{
 "symmetry arguments (",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"\[LeftAngleBracket]", 
        RowBox[{
         SubscriptBox["L", "2"], "|", "V", "|", 
         SubscriptBox["R", "1"]}], "\[RightAngleBracket]"}], "=", 
       RowBox[{
        RowBox[{"\[LeftAngleBracket]", 
         RowBox[{
          SubscriptBox["L", "1"], "|", "V", "|", 
          SubscriptBox["R", "2"]}], "\[RightAngleBracket]"}], "=", "f"}]}], 
      ",", 
      RowBox[{
       RowBox[{
        StyleBox["\[LeftAngleBracket]",
         FontSlant->"Italic"], 
        RowBox[{
         StyleBox[
          SubscriptBox["L", "2"],
          FontSlant->"Italic"], 
         StyleBox["|",
          FontSlant->"Italic"], 
         StyleBox["V",
          FontSlant->"Italic"], 
         StyleBox["|",
          FontSlant->"Italic"], 
         SubscriptBox["L", "1"]}], 
        StyleBox["\[RightAngleBracket]",
         FontSlant->"Italic"]}], 
       StyleBox["=",
        FontSlant->"Italic"], 
       RowBox[{
        RowBox[{"\[LeftAngleBracket]", 
         RowBox[{
          SubscriptBox["R", "1"], 
          StyleBox["|",
           FontSlant->"Italic"], 
          StyleBox["V",
           FontSlant->"Italic"], 
          StyleBox["|",
           FontSlant->"Italic"], 
          StyleBox[
           SubscriptBox["R", "2"],
           FontSlant->"Italic"]}], 
         StyleBox["\[RightAngleBracket]",
          FontSlant->"Italic"]}], 
        StyleBox["=",
         FontSlant->"Italic"], 
        StyleBox["c",
         FontSlant->"Italic"]}]}]}], ")"}], " "}],
   FontSlant->"Italic"]]],
 "require the Hamiltonian to have the following structure in the basis ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"|", 
            SubscriptBox["R", "1"]}], "\[RightAngleBracket]"}], ",", 
          RowBox[{"|", 
           SubscriptBox["L", "1"]}]}], "\[RightAngleBracket]"}], ",", 
        RowBox[{"|", 
         SubscriptBox["R", "2"]}]}], "\[RightAngleBracket]"}], ",", 
      RowBox[{"|", 
       SubscriptBox["L", "2"]}]}], "\[RightAngleBracket]"}], "}"}], 
   TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5300161377006073`*^9, 3.530016159691437*^9}, {
  3.5300164900197887`*^9, 3.530016517179825*^9}, {3.5300165511728907`*^9, 
  3.53001657096413*^9}, {3.530017525468832*^9, 3.530017657411454*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"H", "=", GridBox[{
     {"E1", 
      RowBox[{"-", "A1"}], "c", "f"},
     {
      RowBox[{"-", "A1"}], "E1", "f", "c"},
     {"c", "f", "E2", 
      RowBox[{"-", "A2"}]},
     {"f", "c", 
      RowBox[{"-", "A2"}], "E2"}
    }]}], ";"}]], "Input",
 CellChangeTimes->{{3.53001160160041*^9, 3.530011615135921*^9}, {
   3.530015729897066*^9, 3.530015853968161*^9}, {3.530016190550799*^9, 
   3.530016198272822*^9}, 3.5300165782023773`*^9, 3.530017740878921*^9, {
   3.530018326527248*^9, 3.530018342241534*^9}}],

Cell["\<\
First separate this out into unperturbed and perturbed parts, keeping the \
degenerate subspaces as part of H0\
\>", "Text",
 CellChangeTimes->{{3.530016201859221*^9, 3.5300162148746347`*^9}, {
  3.530016265474105*^9, 3.530016284214373*^9}, {3.530017716181388*^9, 
  3.530017751807598*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"H0", "=", GridBox[{
     {"E1", 
      RowBox[{"-", "A1"}], "0", "0"},
     {
      RowBox[{"-", "A1"}], "E1", "0", "0"},
     {"0", "0", "E2", 
      RowBox[{"-", "A2"}]},
     {"0", "0", 
      RowBox[{"-", "A2"}], "E2"}
    }]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"(", 
   RowBox[{"V", "=", 
    RowBox[{"H", "-", "H0"}]}], ")"}], "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{
  3.5300162223976097`*^9, {3.530017755900876*^9, 3.5300177789068832`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", "c", "f"},
     {"0", "0", "f", "c"},
     {"c", "f", "0", "0"},
     {"f", "c", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.530015856156707*^9, 3.530016224574296*^9, {3.530017758442959*^9, 
   3.530017779914826*^9}, 3.530018345938311*^9}]
}, Open  ]],

Cell["\<\
Find the eigenvalues and vectors for H0 (note much simpler than full H):\
\>", "Text",
 CellChangeTimes->{{3.530016314448403*^9, 3.530016333727275*^9}, {
  3.5300177839440193`*^9, 3.530017784702199*^9}, {3.530017818110506*^9, 
  3.5300178229645567`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"e0s", ",", "kets"}], "}"}], "=", 
  RowBox[{
   RowBox[{"Eigensystem", "[", "H0", "]"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.5300158741183243`*^9, 3.530015892145041*^9}, {
  3.5300177944162617`*^9, 3.530017795055992*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "A1"}], "+", "E1"}], ",", 
     RowBox[{"A1", "+", "E1"}], ",", 
     RowBox[{
      RowBox[{"-", "A2"}], "+", "E2"}], ",", 
     RowBox[{"A2", "+", "E2"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1", ",", "0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "1", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", 
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.530015896824462*^9, 3.5300163400705357`*^9, 
  3.530017796031186*^9, 3.53001834598044*^9}]
}, Open  ]],

Cell[TextData[{
 "Note that the eigenstates are even and odd combinations of the ",
 StyleBox["R",
  FontSlant->"Italic"],
 "s and ",
 StyleBox["L",
  FontSlant->"Italic"],
 "s.  The first and 3rd states are even, the 2nd and 4th odd."
}], "Text",
 CellChangeTimes->{{3.530016845238144*^9, 3.5300169228993177`*^9}, {
  3.530017826220923*^9, 3.530017826645455*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"bras", "=", 
  RowBox[{"Inverse", "[", 
   RowBox[{"kets", "\[Transpose]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.530015905767091*^9, 3.53001591250342*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"], ",", "0", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     FractionBox["1", "2"], ",", 
     FractionBox["1", "2"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", 
     RowBox[{"-", 
      FractionBox["1", "2"]}], ",", 
     FractionBox["1", "2"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.530015914710191*^9, 3.530016349981996*^9, 
  3.530018346026039*^9}]
}, Open  ]],

Cell["\<\
key step: now need to express V in the eigenbasis of H0\
\>", "Text",
 CellChangeTimes->{{3.530015953478663*^9, 3.530015966587405*^9}, {
  3.530016370654932*^9, 3.530016373254744*^9}, {3.530017840813456*^9, 
  3.530017845380086*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"Vp", "=", 
    RowBox[{"bras", ".", "V", ".", 
     RowBox[{"kets", "\[Transpose]"}]}]}], ")"}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.530015990101297*^9, 3.5300160344068727`*^9}, {
  3.5300178764205236`*^9, 3.530017879739954*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"0", "0", 
      RowBox[{"c", "+", "f"}], "0"},
     {"0", "0", "0", 
      RowBox[{"c", "-", "f"}]},
     {
      RowBox[{"c", "+", "f"}], "0", "0", "0"},
     {"0", 
      RowBox[{"c", "-", "f"}], "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.530016003752528*^9, 3.5300160355932426`*^9, 
  3.530017881030648*^9, 3.5300183460966997`*^9}]
}, Open  ]],

Cell["\<\
note that Vp has no diagonal elements, so it has no effect to first order.  \
Note also that Vp only has matrix elements between the two even and the two \
odd eigenstates.
We must therefore use second order perturbation theory.  For the symmetric \
ground state, we get\
\>", "Text",
 CellChangeTimes->{{3.530016675622876*^9, 3.5300167210427094`*^9}, {
  3.530016799679906*^9, 3.5300168387916193`*^9}, {3.530016901764165*^9, 
  3.530016940075673*^9}, {3.530017011488353*^9, 3.530017014201303*^9}, {
  3.530017903585104*^9, 3.530017931416751*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"e0s", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], "+", 
  
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "+", "f"}], ")"}], "2"], 
   RowBox[{
    RowBox[{"e0s", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
    "-", 
    RowBox[{
    "e0s", "\[LeftDoubleBracket]", "3", 
     "\[RightDoubleBracket]"}]}]]}]], "Input",
 CellChangeTimes->{{3.530016816670721*^9, 3.5300168222460623`*^9}, {
  3.530016952028029*^9, 3.530016998795154*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", "A1"}], "+", "E1", "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "+", "f"}], ")"}], "2"], 
   RowBox[{
    RowBox[{"-", "A1"}], "+", "A2", "+", "E1", "-", "E2"}]]}]], "Output",
 CellChangeTimes->{3.530017022933834*^9, 3.530018346138364*^9}]
}, Open  ]],

Cell["\<\
For the antisymmetric ground state, we get\
\>", "Text",
 CellChangeTimes->{{3.530017076337356*^9, 3.530017087736803*^9}, {
  3.5300179926362123`*^9, 3.5300179929804497`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"e0s", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], "+", 
  
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "-", "f"}], ")"}], "2"], 
   RowBox[{
    RowBox[{"e0s", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    "-", 
    RowBox[{
    "e0s", "\[LeftDoubleBracket]", "4", 
     "\[RightDoubleBracket]"}]}]]}]], "Input",
 CellChangeTimes->{{3.530017097284614*^9, 3.5300171280450697`*^9}}],

Cell[BoxData[
 RowBox[{"A1", "+", "E1", "+", 
  FractionBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"c", "-", "f"}], ")"}], "2"], 
   RowBox[{"A1", "-", "A2", "+", "E1", "-", "E2"}]]}]], "Output",
 CellChangeTimes->{{3.5300171156303873`*^9, 3.530017130871695*^9}, 
   3.530018346218808*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{740, 656},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.5, 1.5 Inherited],
FrontEndVersion->"8.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (November 6, \
2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 390, 14, 36, "Subsubsection"],
Cell[972, 38, 2529, 81, 108, "Text"],
Cell[3504, 121, 544, 15, 110, "Input"],
Cell[4051, 138, 300, 6, 62, "Text"],
Cell[CellGroupData[{
Cell[4376, 148, 514, 17, 141, "Input"],
Cell[4893, 167, 798, 22, 126, "Output"]
}, Open  ]],
Cell[5706, 192, 264, 5, 39, "Text"],
Cell[CellGroupData[{
Cell[5995, 201, 291, 7, 40, "Input"],
Cell[6289, 210, 817, 24, 64, "Output"]
}, Open  ]],
Cell[7121, 237, 364, 10, 62, "Text"],
Cell[CellGroupData[{
Cell[7510, 251, 184, 4, 40, "Input"],
Cell[7697, 257, 694, 22, 111, "Output"]
}, Open  ]],
Cell[8406, 282, 243, 5, 39, "Text"],
Cell[CellGroupData[{
Cell[8674, 291, 302, 8, 40, "Input"],
Cell[8979, 301, 882, 25, 126, "Output"]
}, Open  ]],
Cell[9876, 329, 557, 10, 129, "Text"],
Cell[CellGroupData[{
Cell[10458, 343, 517, 15, 74, "Input"],
Cell[10978, 360, 309, 9, 67, "Output"]
}, Open  ]],
Cell[11302, 372, 185, 4, 39, "Text"],
Cell[CellGroupData[{
Cell[11512, 380, 468, 14, 74, "Input"],
Cell[11983, 396, 301, 8, 67, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

